@@ -5,9 +5,9 @@ use strict;
 sub fail {
 
     my($self, @argv) = @_;
-    $main::RESULT = $self->errstr; 
+    $main::RESULT = $self->e->text; 
 	$self->exit_value(1);
-    $self->maybe::next::method(@argv);
+	#$self->maybe::next::method(@argv);
 }
 
 1;
